==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/ownrmat/bean/IdleRecordEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 闲置数量记录实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proownrmat_idle_record")
public class IdleRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_pro_mate_ids")
    private String orgProMateIds; // 采购单位+项目+物料联合主键
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="present_num")
    private BigDecimal presentNum; // 在场数量
    @TableField(value="use_num")
    private BigDecimal useNum; // 使用数量
    @TableField(value="idle_num")
    private BigDecimal idleNum; // 闲置数量


    public String getOrgProMateIds() {
        return orgProMateIds;
    }

    public void setOrgProMateIds(String orgProMateIds) {
        this.orgProMateIds = orgProMateIds;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public BigDecimal getPresentNum() {
        return presentNum;
    }

    public void setPresentNum(BigDecimal presentNum) {
        this.presentNum = presentNum;
    }

    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }

    public BigDecimal getIdleNum() {
        return idleNum;
    }

    public void setIdleNum(BigDecimal idleNum) {
        this.idleNum = idleNum;
    }
}

==> ejc-assistrmat-impl-3.0.0-20220408.080827-57-sources.jar: com/ejianc/business/assist/ownrmat/bean/IdleRecordEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 闲置数量记录实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistownrmat_idle_record")
public class IdleRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_pro_mate_ids")
    private String orgProMateIds; // 采购单位+项目+物料联合主键
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="present_num")
    private BigDecimal presentNum; // 在场数量
    @TableField(value="use_num")
    private BigDecimal useNum; // 使用数量
    @TableField(value="idle_num")
    private BigDecimal idleNum; // 闲置数量


    public String getOrgProMateIds() {
        return orgProMateIds;
    }

    public void setOrgProMateIds(String orgProMateIds) {
        this.orgProMateIds = orgProMateIds;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public BigDecimal getPresentNum() {
        return presentNum;
    }

    public void setPresentNum(BigDecimal presentNum) {
        this.presentNum = presentNum;
    }

    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }

    public BigDecimal getIdleNum() {
        return idleNum;
    }

    public void setIdleNum(BigDecimal idleNum) {
        this.idleNum = idleNum;
    }
}
